==> photo-0.6.tgz: photo-0.6/php/search.php <==
<?php 
 require("user.php");
 require($configfile);
 require("dbconfig.php");
 /**** @ܼ ********/
  //W
 $PROGNAME="search.php";
  //QueryO
 $QUERY="select aid,title,author,pubtime,'<img src={$upload_url}{$ptab}/small/'||filename||'>' from $ptab";
  //TableXSOѼ
 $tabout="border=1";
  //Jܼ
 $ITEM=array("title","author","pubtime","abst","txt");
 if (get_magic_quotes_gpc()==0)
  {
        $title=addslashes($title);
        $author=addslashes($author);
        $abst=addslashes($abst);
        $txt=addslashes($txt);
  }
  //d߸ƪY
 $THEADER=array("s","D","@","o","Y");
  //d߳浧ƪY
 $DTHEADER=array("s","D","@","@Email","o",
  "KnΤި","߱G","ϧ","USER","IP","modtime");
  //浧QueryO
 $DQUERY="select aid,title,author,email,pubtime,abst,txt,'<img src={$upload_url}{$ptab}/'||filename||'>',username,ip,modtime  from $ptab";
 // Primary Key 
 $PKEY="aid";
 /***** {ҥΨ **********/
 $OBJ=$ptab; 
 require("auth.php");
 if (strcmp($PHP_AUTH_USER,"bbs")==0) $ADMIN=0;
 else $ADMIN=1;
 //echo date("Y~mdH:i:s");
 /******** ´dߦr ********/
 if (strlen($LIMIT)==0)
 {
        $numitem=count($ITEM);
        $LIMIT="";
        $flag=0;
        for ($a=0;$a<$numitem;$a++)
        {
          if (strlen($$ITEM[$a])>0)
          {
             if (flag==1)
                $LIMIT=$LIMIT." and ".$ITEM[$a]." like '%".$$ITEM[$a]."%'";
             else
                {
                  $LIMIT=$LIMIT.$ITEM[$a]." like '%".$$ITEM[$a]."%'";
                  $flag=1;
                }
          }
        }
 }
 if (strlen($LIMIT)==0)
 {
        //echo "SJd߸ơIЦAդ@I\n";
        //exit;
        $LIMIT="true";
 }
 if ($DETAIL==1)
    $str=$DQUERY." where ".$LIMIT." order by pubtime DESC";
 else $str=$QUERY." where ".$LIMIT." order by pubtime DESC";
 //echo "$str";
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$str);
 if (!$result){
                        echo "Ʈwd߿~AO $str !";
                        exit;
 }
 $numrow=db_NumRows($result);  
 /******* pGOԲӹ *********/
 if ($DETAIL==1)
 {
    if ($numrow!=1)
    {
        echo "@ $numrow AiOȳ]wDAzud@~I";
        exit;
    }
    $numfield=db_NumFields($result);
    $ARAW=db_fetch_row($result,0); //Ū@O
    if ($ADMIN==1)
    {
       echo "<form method=\"POST\" action=\"prj.php\">";
        echo "<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">\n";
        echo "<input type=\"hidden\" name=\"ptab\" value=\"$ptab\">\n";
        echo "<input type=\"hidden\" name=\"user\" value=\"$user\">\n";
        echo "<input type=\"submit\" name=\"process\" value=\"ק\">\n";
        echo "<input type=\"submit\" name=\"process\" value=\"R\">\n";
       echo "</form>";
    }
    echo "<table $tabout>\n";
    for ($fpt=0;$fpt<$numfield;$fpt++)
    {
     echo "<tr>";
     $special=htmlspecialchars($DTHEADER[$fpt]);//SrBz
     echo "<td>$special</td>";
     if  (strpos($ARAW[$fpt],"<img")===false)
     	$special=nl2br(htmlspecialchars($ARAW[$fpt]));//SrBz
     else
     	$special=($ARAW[$fpt]);//SrBz
     echo "<td>$special</td>";
     echo "</tr>\n";
    }
    echo "</table>";
    exit;
 }

 /****** ȶȬOB˵ *********/
 if ($numrow>500)
   {
        echo "@ $numrow AƤӦhFAЭקd߱AdI";
        exit;
   }
 if ($numrow==0)
   {
        echo "dơAЭקd߱AdI";
        exit;
   }
 $numfield=db_NumFields($result);
 /******** LX ********/
 $PGEND=$PGBEG+$PGNUM-1;
 if ($PGEND>($numrow-1))
 {
        $PGEND=$numrow-1;
 }
  echo "@ $numrow ơI";
 echo "<table border=\"0\"><tr>";
 if ($PGBEG>=$PGNUM)
 {
   $a=$PGBEG-$PGNUM;
   echo "<td><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">\n";
   echo "<input type=\"hidden\" name=\"ptab\" value=\"$ptab\">\n";
   echo "<input type=\"hidden\" name=\"user\" value=\"$user\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"W@\">\n";
   echo "</form></td>\n";
 }
 if ($PGEND<($numrow-1))
 {
   $a=$PGEND+1;
   echo "<td><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">\n";
   echo "<input type=\"hidden\" name=\"ptab\" value=\"$ptab\">\n";
   echo "<input type=\"hidden\" name=\"user\" value=\"$user\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"U@\">\n";
   echo "</form></td>\n";
 }
 echo "</tr></table>\n";
 echo "<table $tabout>\n";
 echo "<tr>";
 for ($fpt=0;$fpt<$numfield;$fpt++)
 {
    $special=htmlspecialchars($THEADER[$fpt]);//SrBz
    echo "<td>$special</td>";
 }
 echo "</tr>";
 for($a=$PGBEG;$a<=$PGEND;$a++)
   {
      echo "<tr>";
      $ARAW=db_fetch_row($result,$a); //Ū@O
      /***** BzĤ@ƥHθԲӾ\Ūu@ ****/
      $tmp=db_FieldNum($result,$PKEY);
      $tmpstr=htmlspecialchars("$PKEY=$ARAW[$tmp]");
      echo "<td><a href=\"$PROGNAME?DETAIL=1&LIMIT=$tmpstr&ptab=$ptab&user=$user\">";
      $special=htmlspecialchars($ARAW[0]);//SrBz
      echo "$special</a></td>";
      for ($fpt=1;$fpt<$numfield;$fpt++)
      {
        if  (strpos($ARAW[$fpt],"<img")!==false)
        	$special=$ARAW[$fpt];//SrBz
	else
        	$special=htmlspecialchars($ARAW[$fpt]);//SrBz
        echo "<td>$special</td>";
      }
      echo "</tr>\n";
   }
   echo "</table>\n";
 if ($PGEND<($numrow-1))
 {
   $a=$PGEND+1;
   echo "<form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">\n";
   echo "<input type=\"hidden\" name=\"ptab\" value=\"$ptab\">\n";
   echo "<input type=\"hidden\" name=\"user\" value=\"$user\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"U@\">\n";
   echo "</form><br>\n";
 }
?>

==> photo-0.52.tgz: photo-0.52/php/search.php <==
<?php 
 require("user.php");
 require($configfile);
 require("dbconfig.php");
 /**** @ܼ ********/
  //W
 $PROGNAME="search.php";
  //QueryO
 $QUERY="select aid,title,author,pubtime,'<img src={$upload_url}{$ptab}/small/'||filename||'>' from $ptab";
  //TableXSOѼ
 $tabout="border=1";
  //Jܼ
 $ITEM=array("title","author","pubtime","abst","txt");
 if (get_magic_quotes_gpc()==0)
  {
        $title=addslashes($title);
        $author=addslashes($author);
        $abst=addslashes($abst);
        $txt=addslashes($txt);
  }
  //d߸ƪY
 $THEADER=array("s","D","@","o","Y");
  //d߳浧ƪY
 $DTHEADER=array("s","D","@","@Email","o",
  "KnΤި","߱G","ϧ","USER","IP","modtime");
  //浧QueryO
 $DQUERY="select aid,title,author,email,pubtime,abst,txt,'<img src={$upload_url}{$ptab}/'||filename||'>',username,ip,modtime  from $ptab";
 // Primary Key 
 $PKEY="aid";
 /***** {ҥΨ **********/
 $OBJ=$ptab; 
 require("auth.php");
 if (strcmp($PHP_AUTH_USER,"bbs")==0) $ADMIN=0;
 else $ADMIN=1;
 //echo date("Y~mdH:i:s");
 /******** ´dߦr ********/
 if (strlen($LIMIT)==0)
 {
        $numitem=count($ITEM);
        $LIMIT="";
        $flag=0;
        for ($a=0;$a<$numitem;$a++)
        {
          if (strlen($$ITEM[$a])>0)
          {
             if (flag==1)
                $LIMIT=$LIMIT." and ".$ITEM[$a]." like '%".$$ITEM[$a]."%'";
             else
                {
                  $LIMIT=$LIMIT.$ITEM[$a]." like '%".$$ITEM[$a]."%'";
                  $flag=1;
                }
          }
        }
 }
 if (strlen($LIMIT)==0)
 {
        //echo "SJd߸ơIЦAդ@I\n";
        //exit;
        $LIMIT="true";
 }
 if ($DETAIL==1)
    $str=$DQUERY." where ".$LIMIT;
 else $str=$QUERY." where ".$LIMIT;
 //echo "$str";
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$str);
 if (!$result){
                        echo "Ʈwd߿~AO $str !";
                        exit;
 }
 $numrow=db_NumRows($result);  
 /******* pGOԲӹ *********/
 if ($DETAIL==1)
 {
    if ($numrow!=1)
    {
        echo "@ $numrow AiOȳ]wDAzud@~I";
        exit;
    }
    $numfield=db_NumFields($result);
    $ARAW=db_fetch_row($result,0); //Ū@O
    if ($ADMIN==1)
    {
       echo "<form method=\"POST\" action=\"prj.php\">";
        echo "<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">\n";
        echo "<input type=\"hidden\" name=\"ptab\" value=\"$ptab\">\n";
        echo "<input type=\"hidden\" name=\"user\" value=\"$user\">\n";
        echo "<input type=\"submit\" name=\"process\" value=\"ק\">\n";
        echo "<input type=\"submit\" name=\"process\" value=\"R\">\n";
       echo "</form>";
    }
    echo "<table $tabout>\n";
    for ($fpt=0;$fpt<$numfield;$fpt++)
    {
     echo "<tr>";
     $special=htmlspecialchars($DTHEADER[$fpt]);//SrBz
     echo "<td>$special</td>";
     if  (strpos($ARAW[$fpt],"<img")===false)
     	$special=nl2br(htmlspecialchars($ARAW[$fpt]));//SrBz
     else
     	$special=($ARAW[$fpt]);//SrBz
     echo "<td>$special</td>";
     echo "</tr>\n";
    }
    echo "</table>";
    exit;
 }

 /****** ȶȬOB˵ *********/
 if ($numrow>500)
   {
        echo "@ $numrow AƤӦhFAЭקd߱AdI";
        exit;
   }
 if ($numrow==0)
   {
        echo "dơAЭקd߱AdI";
        exit;
   }
 $numfield=db_NumFields($result);
 /******** LX ********/
 $PGEND=$PGBEG+$PGNUM-1;
 if ($PGEND>($numrow-1))
 {
        $PGEND=$numrow-1;
 }
  echo "@ $numrow ơI";
 echo "<table border=\"0\"><tr>";
 if ($PGBEG>=$PGNUM)
 {
   $a=$PGBEG-$PGNUM;
   echo "<td><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">\n";
   echo "<input type=\"hidden\" name=\"ptab\" value=\"$ptab\">\n";
   echo "<input type=\"hidden\" name=\"user\" value=\"$user\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"W@\">\n";
   echo "</form></td>\n";
 }
 if ($PGEND<($numrow-1))
 {
   $a=$PGEND+1;
   echo "<td><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">\n";
   echo "<input type=\"hidden\" name=\"ptab\" value=\"$ptab\">\n";
   echo "<input type=\"hidden\" name=\"user\" value=\"$user\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"U@\">\n";
   echo "</form></td>\n";
 }
 echo "</tr></table>\n";
 echo "<table $tabout>\n";
 echo "<tr>";
 for ($fpt=0;$fpt<$numfield;$fpt++)
 {
    $special=htmlspecialchars($THEADER[$fpt]);//SrBz
    echo "<td>$special</td>";
 }
 echo "</tr>";
 for($a=$PGBEG;$a<=$PGEND;$a++)
   {
      echo "<tr>";
      $ARAW=db_fetch_row($result,$a); //Ū@O
      /***** BzĤ@ƥHθԲӾ\Ūu@ ****/
      $tmp=db_FieldNum($result,$PKEY);
      $tmpstr=htmlspecialchars("$PKEY=$ARAW[$tmp]");
      echo "<td><a href=\"$PROGNAME?DETAIL=1&LIMIT=$tmpstr&ptab=$ptab&user=$user\">";
      $special=htmlspecialchars($ARAW[0]);//SrBz
      echo "$special</a></td>";
      for ($fpt=1;$fpt<$numfield;$fpt++)
      {
        if  (strpos($ARAW[$fpt],"<img")!==false)
        	$special=$ARAW[$fpt];//SrBz
	else
        	$special=htmlspecialchars($ARAW[$fpt]);//SrBz
        echo "<td>$special</td>";
      }
      echo "</tr>\n";
   }
   echo "</table>\n";
 if ($PGEND<($numrow-1))
 {
   $a=$PGEND+1;
   echo "<form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">\n";
   echo "<input type=\"hidden\" name=\"ptab\" value=\"$ptab\">\n";
   echo "<input type=\"hidden\" name=\"user\" value=\"$user\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"U@\">\n";
   echo "</form><br>\n";
 }
?>
